@@ -1,20 +1,9 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2009 by Volker Lanz <vl@fidra.de>                *
- *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2014-2020 Andrius Štikonas <andrius@stikonas.eu>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "gui/devicepropsdialog.h"
 #include "gui/devicepropswidget.h"
@@ -30,13 +19,13 @@
 #include <util/helpers.h>
 
 #include <KConfigGroup>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KSharedConfig>
 
 #include <QDialogButtonBox>
 #include <QPointer>
 #include <QPushButton>
+#include <QStyle>
 
 /** Creates a new DevicePropsDialog
     @param parent pointer to the parent widget
@@ -55,7 +44,7 @@ DevicePropsDialog::DevicePropsDialog(QWidget* parent, Device& d) :
     setupDialog();
     setupConnections();
 
-    KConfigGroup kcg(KSharedConfig::openConfig(), "devicePropsDialog");
+    KConfigGroup kcg(KSharedConfig::openConfig(), QStringLiteral("devicePropsDialog"));
     restoreGeometry(kcg.readEntry<QByteArray>("Geometry", QByteArray()));
 
 }
@@ -63,7 +52,7 @@ DevicePropsDialog::DevicePropsDialog(QWidget* parent, Device& d) :
 /** Destroys a DevicePropsDialog */
 DevicePropsDialog::~DevicePropsDialog()
 {
-    KConfigGroup kcg(KSharedConfig::openConfig(), "devicePropsDialog");
+    KConfigGroup kcg(KSharedConfig::openConfig(), QStringLiteral("devicePropsDialog"));
     kcg.writeEntry("Geometry", saveGeometry());
 }
 
@@ -116,10 +105,13 @@ void DevicePropsDialog::setupDialog()
         if (device().smartStatus().isValid()) {
             if (device().smartStatus().status()) {
                 dialogWidget().smartStatusText().setText(xi18nc("@label SMART disk status", "good"));
-                dialogWidget().smartStatusIcon().setPixmap(QIcon::fromTheme(QStringLiteral("dialog-ok")).pixmap(IconSize(KIconLoader::Small)));
+                dialogWidget().smartStatusIcon().setPixmap(QIcon::fromTheme(QStringLiteral("dialog-ok"))
+                            .pixmap(QApplication::style()->pixelMetric(QStyle::PixelMetric::PM_SmallIconSize)));
+
             } else {
                 dialogWidget().smartStatusText().setText(xi18nc("@label SMART disk status", "BAD"));
-                dialogWidget().smartStatusIcon().setPixmap(QIcon::fromTheme(QStringLiteral("dialog-warning")).pixmap(IconSize(KIconLoader::Small)));
+                dialogWidget().smartStatusIcon().setPixmap(QIcon::fromTheme(QStringLiteral("dialog-warning"))
+                            .pixmap(QApplication::style()->pixelMetric(QStyle::PixelMetric::PM_SmallIconSize)));
             }
         } else {
             dialogWidget().smartStatusText().setText(xi18nc("@label", "(unknown)"));
